#!/bin/sh

chmod 755 txt2pot.py
./txt2pot.py

msguniq -s tuxpaint-stamps.pot > temp.tmp && mv -f temp.tmp tuxpaint-stamps.pot
for i in *.po ; do
  echo $i
  msgmerge --sort-output --update --previous --no-wrap $i tuxpaint-stamps.pot
done
